﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Tilengine;

public class TilengineHandler : MonoBehaviour
{
    public int renderWidth;
    public int renderHeight;
    public int numLayers;
    public int numSprites;
    public int numAnims;

    private Texture2D renderTexture;
    private byte[] renderPixels;
    private int frameCounter;
    public static Engine renderEngine;

    private Tilengine.Sprite trialManSprite;
    private Spriteset trialManSet;
    private Tilengine.Animation trialManAnim;
    // Start is called before the first frame update
    void Start()
    {
        if (this.renderWidth <= 0) { this.renderWidth = 1; }
        if (this.renderHeight <= 0) { this.renderHeight = 1; }
        this.frameCounter = 0;

        Camera primeCamera = Camera.main;
        if (primeCamera.orthographic) {
            Transform renderTransform = this.GetComponent<Transform>();
            float renderRatio = (float)this.renderWidth / (float)this.renderHeight;
            float renderScale = primeCamera.orthographicSize * 2.0f;
            renderTransform.localScale = new Vector3(renderScale * renderRatio, renderScale, 1.0f);
        }

        this.renderTexture = new Texture2D(this.renderWidth, this.renderHeight, TextureFormat.BGRA32, false, false);
        this.renderTexture.anisoLevel = 0;
        this.renderTexture.filterMode = FilterMode.Point;
        Renderer localRenderer = this.GetComponent<Renderer>();
        localRenderer.material.mainTexture = this.renderTexture;

        int byteCount = this.renderWidth * this.renderHeight * 4;
        this.renderPixels = new byte[byteCount];

        //TileEngineHandler.renderEngeine
        TilengineHandler.renderEngine = Engine.Init(this.renderWidth, this.renderHeight, this.numLayers, this.numSprites, this.numAnims);
        TilengineHandler.renderEngine.LoadPath = "Assets/Graphics";
        TilengineHandler.renderEngine.SetRenderTarget(this.renderPixels, this.renderWidth * 4);
        TilengineHandler.renderEngine.SetBackgroundColor(new Tilengine.Color(0x77, 0x77, 0x77));

        this.trialManSprite = TilengineHandler.renderEngine.Sprites[0];
        this.trialManSet = Spriteset.FromFile("trialMan");
        this.trialManSprite.Setup(this.trialManSet, TileFlags.None);

        SequencePack trialManSeqPack = SequencePack.FromFile("trialMan.sqx");
        Sequence trialManSeq = trialManSeqPack.Find("armWave");
        this.trialManAnim = TilengineHandler.renderEngine.Animations[0];
        this.trialManAnim.SetSpriteAnimation(this.trialManSprite.index, trialManSeq, 0);

        this.trialManSprite.SetPosition(8, 8);
    }

    // Update is called once per frame
    void Update()
    {
        TilengineHandler.renderEngine.UpdateFrame(this.frameCounter);
        this.frameCounter++;
        this.renderTexture.LoadRawTextureData(this.renderPixels);
        this.renderTexture.Apply();
    }
}
